==> qmmp-0.4.1.tar.bz2: qmmp-0.4.1/src/plugins/General/notifier/translations/notifier_plugin_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="it">
<context>
    <name>NotifierFactory</name>
    <message>
        <location filename="../notifierfactory.cpp" line="30"/>
        <source>Notifier Plugin</source>
        <translation>Modulo notifica</translation>
    </message>
    <message>
        <location filename="../notifierfactory.cpp" line="50"/>
        <source>About Notifier Plugin</source>
        <translation>Info sul modulo notifica</translation>
    </message>
    <message>
        <location filename="../notifierfactory.cpp" line="51"/>
        <source>Qmmp Notifier Plugin</source>
        <translation>Modulo notifica per Qmmp</translation>
    </message>
    <message>
        <location filename="../notifierfactory.cpp" line="52"/>
        <source>Writen by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Autore: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>PopupWidget</name>
    <message>
        <location filename="../popupwidget.cpp" line="126"/>
        <source>Volume:</source>
        <translation>Volume:</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="390"/>
        <source>Psi Notification</source>
        <translation>Notifica Psi</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="402"/>
        <source>Enable Psi notification</source>
        <translation>Abilita notifica Psi</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="35"/>
        <source>Desktop Notification</source>
        <translation>Notifica sul desktop</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="75"/>
        <source>Delay (ms):</source>
        <translation>Ritardo (ms):</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="101"/>
        <source>Transparency:</source>
        <translation>Trasparenza:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="281"/>
        <source>Position</source>
        <translation>Posizione</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>Notifier Plugin Settings</source>
        <translation>Impostazioni modulo notifica</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="41"/>
        <source>Song change notification</source>
        <translation>Notifica cambio brano</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="48"/>
        <source>Volume change notification</source>
        <translation>Notifica modifica volume</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="124"/>
        <location filename="../settingsdialog.ui" line="334"/>
        <source>0</source>
        <translation>0</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="344"/>
        <source>Notification Template</source>
        <translation>Modello di notificazione</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="373"/>
        <source>Reset</source>
        <translation>Azzera</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="380"/>
        <source>Insert</source>
        <translation>Inserisci</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="55"/>
        <source>Font:</source>
        <translation>Carattere;</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="308"/>
        <source>Cover size:</source>
        <translation>Dimensione copertina:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="301"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="107"/>
        <source>Artist</source>
        <translation>Artista</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="108"/>
        <source>Album</source>
        <translation>Album</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="109"/>
        <source>Title</source>
        <translation>Titolo</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="110"/>
        <source>Track number</source>
        <translation>Traccia n°</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="111"/>
        <source>Two-digit track number</source>
        <translation>Traccia n° a due cifre</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="112"/>
        <source>Genre</source>
        <translation>Genere</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="113"/>
        <source>Comment</source>
        <translation>Commento</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="114"/>
        <source>Composer</source>
        <translation>Compositore</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="115"/>
        <source>Duration</source>
        <translation>Durata</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="116"/>
        <source>Disc number</source>
        <translation>Disco n°</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="117"/>
        <source>File name</source>
        <translation>Nome file</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="118"/>
        <source>File path</source>
        <translation>Percorso file</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="119"/>
        <source>Year</source>
        <translation>Anno</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="120"/>
        <source>Condition</source>
        <translation>Condizione</translation>
    </message>
</context>
</TS>

==> qmmp-0.4.5.tar.bz2: qmmp-0.4.5/src/plugins/General/notifier/translations/notifier_plugin_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="it">
<context>
    <name>NotifierFactory</name>
    <message>
        <location filename="../notifierfactory.cpp" line="30"/>
        <source>Notifier Plugin</source>
        <translation>Modulo notifica</translation>
    </message>
    <message>
        <location filename="../notifierfactory.cpp" line="50"/>
        <source>About Notifier Plugin</source>
        <translation>Info sul modulo notifica</translation>
    </message>
    <message>
        <location filename="../notifierfactory.cpp" line="51"/>
        <source>Qmmp Notifier Plugin</source>
        <translation>Modulo notifica per Qmmp</translation>
    </message>
    <message>
        <location filename="../notifierfactory.cpp" line="52"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Autore: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>PopupWidget</name>
    <message>
        <location filename="../popupwidget.cpp" line="127"/>
        <source>Volume:</source>
        <translation>Volume:</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="390"/>
        <source>Psi Notification</source>
        <translation>Notifica Psi</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="402"/>
        <source>Enable Psi notification</source>
        <translation>Abilita notifica Psi</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="35"/>
        <source>Desktop Notification</source>
        <translation>Notifica sul desktop</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="75"/>
        <source>Delay (ms):</source>
        <translation>Ritardo (ms):</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="101"/>
        <source>Transparency:</source>
        <translation>Trasparenza:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="281"/>
        <source>Position</source>
        <translation>Posizione</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>Notifier Plugin Settings</source>
        <translation>Impostazioni modulo notifica</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="41"/>
        <source>Song change notification</source>
        <translation>Notifica cambio brano</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="48"/>
        <source>Volume change notification</source>
        <translation>Notifica modifica volume</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="124"/>
        <location filename="../settingsdialog.ui" line="334"/>
        <source>0</source>
        <translation>0</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="344"/>
        <source>Notification Template</source>
        <translation>Modello di notificazione</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="373"/>
        <source>Reset</source>
        <translation>Azzera</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="380"/>
        <source>Insert</source>
        <translation>Inserisci</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="55"/>
        <source>Font:</source>
        <translation>Carattere;</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="308"/>
        <source>Cover size:</source>
        <translation>Dimensione copertina:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="301"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="107"/>
        <source>Artist</source>
        <translation>Artista</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="108"/>
        <source>Album</source>
        <translation>Album</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="109"/>
        <source>Title</source>
        <translation>Titolo</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="110"/>
        <source>Track number</source>
        <translation>Traccia n°</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="111"/>
        <source>Two-digit track number</source>
        <translation>Traccia n° a due cifre</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="112"/>
        <source>Genre</source>
        <translation>Genere</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="113"/>
        <source>Comment</source>
        <translation>Commento</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="114"/>
        <source>Composer</source>
        <translation>Compositore</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="115"/>
        <source>Duration</source>
        <translation>Durata</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="116"/>
        <source>Disc number</source>
        <translation>Disco n°</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="117"/>
        <source>File name</source>
        <translation>Nome file</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="118"/>
        <source>File path</source>
        <translation>Percorso file</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="119"/>
        <source>Year</source>
        <translation>Anno</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="120"/>
        <source>Condition</source>
        <translation>Condizione</translation>
    </message>
</context>
</TS>
